@@ -498,7 +498,6 @@ Dispatcher::~Dispatcher() noexcept
   DispatchNotifier::unreference_instance(impl_->notifier_, impl_);
 }
 
-#ifndef GLIBMM_DISABLE_DEPRECATED
 void
 Dispatcher::emit()
 {
@@ -510,19 +509,6 @@ Dispatcher::operator()()
 {
   impl_->notifier_->send_notification(impl_);
 }
-#endif // GLIBMM_DISABLE_DEPRECATED
-
-void
-Dispatcher::emit() const
-{
-  impl_->notifier_->send_notification(impl_);
-}
-
-void
-Dispatcher::operator()() const
-{
-  impl_->notifier_->send_notification(impl_);
-}
 
 sigc::connection
 Dispatcher::connect(const sigc::slot<void()>& slot)
